From c4c23b471528c582b8c4133a834e46c539f234c6 Mon Sep 17 00:00:00 2001
From: gbellato <gbellato@localhost>
Date: Fri, 06 Jul 2007 10:12:08 +0000
Subject: [PATCH] fix for isue 1632 : schema check should not be done for replicated operation.

---
 opends/src/server/org/opends/server/core/ModifyDNOperation.java |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/opends/src/server/org/opends/server/core/ModifyDNOperation.java b/opends/src/server/org/opends/server/core/ModifyDNOperation.java
index 979f3ac..80db37b 100644
--- a/opends/src/server/org/opends/server/core/ModifyDNOperation.java
+++ b/opends/src/server/org/opends/server/core/ModifyDNOperation.java
@@ -1501,9 +1501,11 @@
           }
         }
 
-
-        // Make sure that the resulting entry is valid as per the server schema.
-        if (DirectoryServer.checkSchema())
+        // If the server is configured to check the schema and the
+        // operation is not a synchronization operation,
+        // make sure that the resulting entry is valid as per the server schema.
+        if ((DirectoryServer.checkSchema()) &&
+            (!isSynchronizationOperation()) )
         {
           StringBuilder invalidReason = new StringBuilder();
           if (! newEntry.conformsToSchema(null, false, true, true,

--
Gitblit v1.10.0